@@ -125,6 +125,11 @@ class RpcExchangerClient:
             self._username = username
         return uid
 
+    async def register(self, username: str, password: str) -> bool:
+        # Note: this only register, won't login
+        success = await self._rpc.register(username=username, password=password)
+        return success
+
     def check_authorized(self) -> None:
         if self._uid is None or self._username is None:
             raise NotAuthorizedError()
